==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ActionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ActionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Actions to invoke when the alert fires.
 * @property actionGroups Action Group resource Ids to invoke when the alert fires.
 * @property actionProperties The properties of an action properties.
 * @property customProperties The properties of an alert payload.
 */
public data class ActionsArgs(
    public val actionGroups: Output<List<String>>? = null,
    public val actionProperties: Output<Map<String, String>>? = null,
    public val customProperties: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ActionsArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.ActionsArgs =
        com.pulumi.azurenative.insights.inputs.ActionsArgs.builder()
            .actionGroups(actionGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .actionProperties(
                actionProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .customProperties(
                customProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ActionsArgs].
 */
@PulumiTagMarker
public class ActionsArgsBuilder internal constructor() {
    private var actionGroups: Output<List<String>>? = null

    private var actionProperties: Output<Map<String, String>>? = null

    private var customProperties: Output<Map<String, String>>? = null

    /**
     * @param value Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("auyhxtxmdmmuvxjb")
    public suspend fun actionGroups(`value`: Output<List<String>>) {
        this.actionGroups = value
    }

    @JvmName("awmuousmyqaxsoye")
    public suspend fun actionGroups(vararg values: Output<String>) {
        this.actionGroups = Output.all(values.asList())
    }

    /**
     * @param values Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("naunyvieombrxwnf")
    public suspend fun actionGroups(values: List<Output<String>>) {
        this.actionGroups = Output.all(values)
    }

    /**
     * @param value The properties of an action properties.
     */
    @JvmName("ibnyuscyhjloypyk")
    public suspend fun actionProperties(`value`: Output<Map<String, String>>) {
        this.actionProperties = value
    }

    /**
     * @param value The properties of an alert payload.
     */
    @JvmName("cfkocdpgponogcji")
    public suspend fun customProperties(`value`: Output<Map<String, String>>) {
        this.customProperties = value
    }

    /**
     * @param value Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("dyoubptykbqwewfq")
    public suspend fun actionGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionGroups = mapped
    }

    /**
     * @param values Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("vgptbtslrchxcfof")
    public suspend fun actionGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionGroups = mapped
    }

    /**
     * @param value The properties of an action properties.
     */
    @JvmName("fveuxhwfgcfmdslf")
    public suspend fun actionProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionProperties = mapped
    }

    /**
     * @param values The properties of an action properties.
     */
    @JvmName("qlantxnsdhyaomsn")
    public fun actionProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionProperties = mapped
    }

    /**
     * @param value The properties of an alert payload.
     */
    @JvmName("aulhlwyblbwhqntj")
    public suspend fun customProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    /**
     * @param values The properties of an alert payload.
     */
    @JvmName("jnjbirpumucbycpo")
    public fun customProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    internal fun build(): ActionsArgs = ActionsArgs(
        actionGroups = actionGroups,
        actionProperties = actionProperties,
        customProperties = customProperties,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ActionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ActionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Actions to invoke when the alert fires.
 * @property actionGroups Action Group resource Ids to invoke when the alert fires.
 * @property actionProperties The properties of an action properties.
 * @property customProperties The properties of an alert payload.
 */
public data class ActionsArgs(
    public val actionGroups: Output<List<String>>? = null,
    public val actionProperties: Output<Map<String, String>>? = null,
    public val customProperties: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ActionsArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.ActionsArgs =
        com.pulumi.azurenative.insights.inputs.ActionsArgs.builder()
            .actionGroups(actionGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .actionProperties(
                actionProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .customProperties(
                customProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ActionsArgs].
 */
@PulumiTagMarker
public class ActionsArgsBuilder internal constructor() {
    private var actionGroups: Output<List<String>>? = null

    private var actionProperties: Output<Map<String, String>>? = null

    private var customProperties: Output<Map<String, String>>? = null

    /**
     * @param value Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("udkfhnqwobcetfwa")
    public suspend fun actionGroups(`value`: Output<List<String>>) {
        this.actionGroups = value
    }

    @JvmName("olikxomoveddsjko")
    public suspend fun actionGroups(vararg values: Output<String>) {
        this.actionGroups = Output.all(values.asList())
    }

    /**
     * @param values Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("aggwtmogsywnatic")
    public suspend fun actionGroups(values: List<Output<String>>) {
        this.actionGroups = Output.all(values)
    }

    /**
     * @param value The properties of an action properties.
     */
    @JvmName("vqcirnwxqmtbrqha")
    public suspend fun actionProperties(`value`: Output<Map<String, String>>) {
        this.actionProperties = value
    }

    /**
     * @param value The properties of an alert payload.
     */
    @JvmName("xipptjdmnvnjbwnq")
    public suspend fun customProperties(`value`: Output<Map<String, String>>) {
        this.customProperties = value
    }

    /**
     * @param value Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("ntimvfmrnubboeum")
    public suspend fun actionGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionGroups = mapped
    }

    /**
     * @param values Action Group resource Ids to invoke when the alert fires.
     */
    @JvmName("bkedotnmonixhsrn")
    public suspend fun actionGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionGroups = mapped
    }

    /**
     * @param value The properties of an action properties.
     */
    @JvmName("txhecpmnecccfgml")
    public suspend fun actionProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionProperties = mapped
    }

    /**
     * @param values The properties of an action properties.
     */
    @JvmName("ytclvnfdusygkkrn")
    public fun actionProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actionProperties = mapped
    }

    /**
     * @param value The properties of an alert payload.
     */
    @JvmName("twkuogpgokgdpsxy")
    public suspend fun customProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    /**
     * @param values The properties of an alert payload.
     */
    @JvmName("wtqotcctumncngta")
    public fun customProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customProperties = mapped
    }

    internal fun build(): ActionsArgs = ActionsArgs(
        actionGroups = actionGroups,
        actionProperties = actionProperties,
        customProperties = customProperties,
    )
}
